excerpts: excerpts.command_line Namespace Reference

excerpts

- Main Page
- Packages
- Files

- Packages
- Package Functions

All Namespaces Files Functions
Functions
excerpts.command_line Namespace Reference

## Functions
def | make_parser
| Use a Custom Parser Function. More...
def | main
| A User Command Line Interface. More...

## Function Documentation

def excerpts.command_line.main | ( |  | ) |

A User Command Line Interface.

Here is the call graph for this function:

def excerpts.command_line.make_parser | ( |  | ) |

Use a Custom Parser Function.

To keep main() tiny.

Here is the call graph for this function: